@@ -67,6 +67,11 @@ class Status:
                         "ext_info": self.father.framework.machine.get_user_config_items("EXTINFO")
                     }
 
+                    user_data["ext_info"]["max_linear_velocity"] = float(inifile.find("DISPLAY", "MAX_LINEAR_VELOCITY"))
+                    user_data["ext_info"]["default_linear_velocity"] = float(inifile.find("DISPLAY", "DEFAULT_LINEAR_VELOCITY"))
+                    user_data["ext_info"]["max_angular_velocity"] = float(inifile.find("DISPLAY", "MAX_ANGULAR_VELOCITY"))
+                    user_data["ext_info"]["default_angular_velocity"] = float(inifile.find("DISPLAY", "DEFAULT_ANGULAR_VELOCITY"))
+
                     self.father.framework.machine.info["user_data"] = user_data
 
                     self.father.framework.machine.axis = user_data["coordinates"]
